==> ajv-2.2.2.tgz: package/lib/dotjs/format.js <==
'use strict';
module.exports = function generate_format(it) {
  var out = ' ';
  var $lvl = it.level,
    $dataLvl = it.dataLevel,
    $schema = it.schema['format'],
    $schemaPath = it.schemaPath + '.' + 'format',
    $breakOnError = !it.opts.allErrors;
  var $data = 'data' + ($dataLvl || ''),
    $valid = 'valid' + $lvl,
    $errs = 'errs' + $lvl;
  var $format = it.formats[$schema];
  var $isObject = typeof $format == 'object' && !($format instanceof RegExp) && $format.validate;
  if ($isObject) $format = $format.validate;
  if (it.opts.format !== false && $format) {
    out += ' if (!   ';
    if (typeof $format == 'function') {
      out += '  formats' + (it.util.getProperty($schema));
      if ($isObject) {
        out += '.validate';
      }
      out += '(' + ($data) + ') ';
    } else {
      out += '  formats' + (it.util.getProperty($schema));
      if ($isObject) {
        out += '.validate';
      }
      out += '.test(' + ($data) + ') ';
    }
    out += ') {  ';
    if (!it.compositeRule && $breakOnError) {
      out += ' validate.errors = [ { keyword: \'' + ('format') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: "' + ($schemaPath) + '" , params: { format: \'' + (it.util.escapeQuotes($schema)) + '\' } ';
      if (it.opts.messages !== false) {
        out += ' , message: \'should match format ' + (it.util.escapeQuotes($schema)) + '\' ';
      }
      if (it.opts.verbose) {
        out += ' , schema: ' + (it.util.toQuotedString($schema)) + ' , data: ' + ($data) + ' ';
      }
      out += ' }]; return false; ';
    } else {
      out += '  var err =   { keyword: \'' + ('format') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: "' + ($schemaPath) + '" , params: { format: \'' + (it.util.escapeQuotes($schema)) + '\' } ';
      if (it.opts.messages !== false) {
        out += ' , message: \'should match format ' + (it.util.escapeQuotes($schema)) + '\' ';
      }
      if (it.opts.verbose) {
        out += ' , schema: ' + (it.util.toQuotedString($schema)) + ' , data: ' + ($data) + ' ';
      }
      out += ' }; if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
    }
    out += ' } ';
    if ($breakOnError) {
      out += ' else { ';
    }
  } else {
    if ($breakOnError) {
      out += ' if (true) { ';
    }
  }
  return out;
}

==> ajv-2.3.0.tgz: package/lib/dotjs/format.js <==
'use strict';
module.exports = function generate_format(it) {
  var out = ' ';
  var $lvl = it.level,
    $dataLvl = it.dataLevel,
    $schema = it.schema['format'],
    $schemaPath = it.schemaPath + '.' + 'format',
    $breakOnError = !it.opts.allErrors;
  var $data = 'data' + ($dataLvl || ''),
    $valid = 'valid' + $lvl,
    $errs = 'errs' + $lvl;
  var $format = it.formats[$schema];
  var $isObject = typeof $format == 'object' && !($format instanceof RegExp) && $format.validate;
  if ($isObject) $format = $format.validate;
  if (it.opts.format !== false && $format) {
    out += ' if (!   ';
    if (typeof $format == 'function') {
      out += '  formats' + (it.util.getProperty($schema));
      if ($isObject) {
        out += '.validate';
      }
      out += '(' + ($data) + ') ';
    } else {
      out += '  formats' + (it.util.getProperty($schema));
      if ($isObject) {
        out += '.validate';
      }
      out += '.test(' + ($data) + ') ';
    }
    out += ') {  ';
    if (!it.compositeRule && $breakOnError) {
      out += ' validate.errors = [ { keyword: \'' + ('format') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: "' + ($schemaPath) + '" , params: { format: \'' + (it.util.escapeQuotes($schema)) + '\' } ';
      if (it.opts.messages !== false) {
        out += ' , message: \'should match format ' + (it.util.escapeQuotes($schema)) + '\' ';
      }
      if (it.opts.verbose) {
        out += ' , schema: ' + (it.util.toQuotedString($schema)) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
      }
      out += ' }]; return false; ';
    } else {
      out += '  var err =   { keyword: \'' + ('format') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: "' + ($schemaPath) + '" , params: { format: \'' + (it.util.escapeQuotes($schema)) + '\' } ';
      if (it.opts.messages !== false) {
        out += ' , message: \'should match format ' + (it.util.escapeQuotes($schema)) + '\' ';
      }
      if (it.opts.verbose) {
        out += ' , schema: ' + (it.util.toQuotedString($schema)) + ' , parentSchema: validate.schema' + (it.schemaPath) + ' , data: ' + ($data) + ' ';
      }
      out += ' }; if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
    }
    out += ' } ';
    if ($breakOnError) {
      out += ' else { ';
    }
  } else {
    if ($breakOnError) {
      out += ' if (true) { ';
    }
  }
  return out;
}
